export declare abstract class Try<T> {
    protected constructor();
    static successFactory: <T>(value: T) => Try<T>;
    static failureFactory: <T>(ex: Error) => Try<T>;
    static success<T>(value: T): Try<T>;
    static failure<T>(ex: Error): Try<T>;
    map<U>(f: (v: T) => U): Try<U>;
    flatMap<U>(f: (v: T) => Try<U>): Try<U>;
    static of<U>(f: () => U): Try<U>;
    abstract getCause(): Error;
    abstract isSuccess(): boolean;
    abstract isFailure(): boolean;
    abstract get(): T;
    getOrElse<U>(fallbackValue: U): T | U;
    getOrElseGet<U>(fallbackFunction: (ex: Error) => U): T | U;
    getOrElseThrow<Error>(fallbackFunction: () => Error): T;
    andThen(f: (v: T) => void): Try<T>;
    filter(predicate: (v: T) => boolean, fallbackFunction?: () => Error): Try<T>;
    filterNot(predicate: (v: T) => boolean, fallbackFunction?: () => Error): Try<T>;
    peek(f: (v: T) => void): Try<T>;
    recover<U>(recoverMapping: {
        [key: string]: U;
    }): Try<U | T>;
    recoverWith<U>(recoverMapping: {
        [key: string]: (ex: Error) => U;
    }): Try<T>;
    recoverWith<U>(recoverMapping: {
        [key: string]: (ex: Error) => U;
    }): Try<U>;
    onSuccess(f: (v: T) => void): Try<T>;
    onFailure(f: (ex: Error) => void): Try<T>;
}
